pub const unsafe fn encode() -> EncodedX86_64InstructionExpand description
No operation.
Safety
This function is safe to call. It is marked as unsafe for consistency with other encoders.
pub const unsafe fn encode() -> EncodedX86_64InstructionNo operation.
This function is safe to call. It is marked as unsafe for consistency with other encoders.